#[repr(C)]pub struct Price {
pub raw: PriceRaw,
pub precision: u8,
}Expand description
Represents a price in a market with a specified precision.
The number of decimal places may vary. For certain asset classes, prices may have negative values. For example, prices for options instruments can be negative under certain conditions.
Handles up to FIXED_PRECISION decimals of precision.
Fields
raw: PriceRawRepresents the raw fixed-point value, with precision defining the number of decimal places.
precision: u8The number of decimal places, with a maximum of FIXED_PRECISION.
Implementations
Sourceimpl Price
impl Price
Sourcepub fn new_checked(value: f64, precision: u8) -> Result<Self>
pub fn new_checked(value: f64, precision: u8) -> Result<Self>
Creates a new Price instance with correctness checking.
Errors
Returns an error if:
valueis invalid outside the representable range [PRICE_MIN,PRICE_MAX].precisionis invalid outside the representable range [0, `FIXED_PRECISION``].
Notes
PyO3 requires a Result type for proper error handling and stacktrace printing in Python.
Sourcepub fn new(value: f64, precision: u8) -> Self
pub fn new(value: f64, precision: u8) -> Self
Creates a new Price instance.
Panics
Panics if a correctness check fails. See Price::new_checked for more details.
Sourcepub fn from_raw(raw: PriceRaw, precision: u8) -> Self
pub fn from_raw(raw: PriceRaw, precision: u8) -> Self
Creates a new Price instance from the given raw fixed-point value and precision.
Panics
Panics if a correctness check fails. See Price::new_checked for more details.
Sourcepub fn zero(precision: u8) -> Self
pub fn zero(precision: u8) -> Self
Creates a new Price instance with a value of zero with the given precision.
Panics
Panics if a correctness check fails. See Price::new_checked for more details.
Sourcepub fn max(precision: u8) -> Self
pub fn max(precision: u8) -> Self
Creates a new Price instance with the maximum representable value with the given precision.
Panics
Panics if a correctness check fails. See Price::new_checked for more details.
Sourcepub fn min(precision: u8) -> Self
pub fn min(precision: u8) -> Self
Creates a new Price instance with the minimum representable value with the given precision.
Panics
Panics if a correctness check fails. See Price::new_checked for more details.
Sourcepub fn is_undefined(&self) -> bool
pub fn is_undefined(&self) -> bool
Returns true if the value of this instance is undefined.
Sourcepub fn is_positive(&self) -> bool
pub fn is_positive(&self) -> bool
Returns true if the value of this instance is position (> 0).
Sourcepub fn as_f64(&self) -> f64
pub fn as_f64(&self) -> f64
Returns the value of this instance as an f64.
Panics
Panics if precision is beyond MAX_FLOAT_PRECISION (16).
Sourcepub fn as_decimal(&self) -> Decimal
pub fn as_decimal(&self) -> Decimal
Returns the value of this instance as a Decimal.
Sourcepub fn to_formatted_string(&self) -> String
pub fn to_formatted_string(&self) -> String
Returns a formatted string representation of this instance.
Sourcepub fn from_decimal(decimal: Decimal, precision: u8) -> Result<Self>
pub fn from_decimal(decimal: Decimal, precision: u8) -> Result<Self>
Creates a new Price from a Decimal value with specified precision.
This method provides more reliable parsing by using Decimal arithmetic to avoid floating-point precision issues during conversion.
Errors
Returns an error if:
precisionexceedsFIXED_PRECISION.- The decimal value cannot be converted to the raw representation.
- Overflow occurs during scaling.